MultiLanguageTranslationMap

Struct MultiLanguageTranslationMap 

pub struct MultiLanguageTranslationMap<K: Hash + PartialEq + Eq + Debug + Clone = String> { /* private fields */ }

Implementations

Source

impl MultiLanguageTranslationMap

pub fn new( source_path: &str, source_contents: &str, ) -> CountriesIso31661Result<Self>

Available on crate feature std only.
pub fn get_translation( &self, identifier: &str, bcp47_code: &str, ) -> CountriesIso31661Result<String>

Available on crate feature std only.

Identifier and BCP-47 Code are case sensitive

pub fn identifier_index(&self) -> &HashMap<String, usize>

Available on crate feature std only.

If large_keys feature is enabled the result of this is a &HashMap<u64, usize>

pub fn bcp47_index(&self) -> &HashMap<String, usize>

Available on crate feature std only.
pub fn translations(&self) -> &[Vec<String>]

Available on crate feature std only.
pub fn parse( source_path: &str, input: &str, ) -> CountriesIso31661Result<HashMap<String, Vec<(String, String)>>>

Available on crate feature std only.

The start of a sentence must have a space #